#!/usr/bin/env python

import boto3
import os
import time
from os import system, path
from ec2 import describe_instances, start_instances, stop_instances
from route53 import check_domain_availability

# Set our default profile and region
session = boto3.Session(profile_name="default")
aws_region = "us-east-1"


class AWSProfile(object):
    """
    Method to change AWS profile and region.
    Multiple regions must be configured first in
    ~/.aws/{congig, credentails} files.
    """
    def __init__(self):
        global session
        global aws_region
        system("clear")
        data_folder = os.path.expanduser("~/.aws/")
        aws_file = os.path.join(data_folder, "config")
        aws_config = open(aws_file)
        print(aws_config.read())
        aws_profile = input("Type profile name: ")
        session = boto3.Session(profile_name=aws_profile)
        system("clear")
        print("Select region:")
        print("1. Cape Town (af-south-1)")
        print("2. London (eu-west-2)")
        choice = input("> ")
        if choice == "1":
            aws_region = "af-south-1"
        elif choice == "2":
            aws_region = "eu-west-2"
        else:
            print("Invalid option")
            time.sleep(2)
            aws_menu()
        aws_menu()
        


class EC2(object):
    """
    Menu options to manage EC2 methods imported
    from ec2.py
    Allows for listing, starting and stopping instances.
    """
    def __init__(self):
        self.client = session.client("ec2", region_name = aws_region)
    
    def ec2_menu(self):
        system("clear")
        print("AWS EC2")
        print(f"Profile: {session.profile_name} <> Region: {aws_region}")
        print("")
        print("1. List instances + status")
        print("2. Start instance")
        print("3. Stop instance")
        print("8. Back")
        print("9. Exit")
        choice = input("> ")
        if choice == "1":
            describe_instances(self.client)
            EC2.ec2_menu(self)
        elif choice == "2":
            start_instances(self.client)
            EC2.ec2_menu(self)
        elif choice == "3":
            stop_instances(self.client)
            EC2.ec2_menu(self)
        elif choice == "8":
            aws_menu()
        elif choice == "9":
            system("exit")
        else:
            print("Invalid option")
            time.sleep(2)
            EC2().ec2_menu()


class Route53(object):
    """
    Menu options to manage Route53 methods imported
    from route53.py
    Allows for searching domain registration availability.
    """
    def __init__(self):
        self.client = session.client("route53domains", region_name = "us-east-1")

    def route53_menu(self):
        system("clear")
        print("AWS Route53")
        print(f"Profile: {session.profile_name} <> Region: {aws_region}")
        print("")
        print("1. Domain Availability")
        print("8. Back")
        print("9. Exit")
        choice = input("> ")
        if choice == "1":
            check_domain_availability(self.client)
            Route53.route53_menu(self)
        elif choice == "8":
            aws_menu()
        elif choice == "9":
            system("exit")
        else:
            print("Invalid option")
            time.sleep(2)
            Route53().route53_menu()

    
def aws_menu():
    """
    Main menu.
    """
    system("clear")
    print("AWS CLI")
    print(f"Profile: {session.profile_name} <> Region: {aws_region}")
    print("")
    print("1. Change Profile & Region")
    print("2. Route53")
    print("3. EC2")
    print("9. Exit")
    choice = input("> ")
    if choice == "1":
        AWSProfile()
    elif choice == "2":
        Route53().route53_menu()
    elif choice == "3":
        EC2().ec2_menu()
    elif choice == "9":
        system("exit")
    else:
        print("Invalid option")
        time.sleep(2)
        aws_menu()



if __name__ == "__main__":
    aws_menu()


#!/usr/bin/env python
from os import system


def describe_instances(client):
    """
    List instances for AWS profile in chosen region.
    """
    response = client.describe_instances()
    for key in response["Reservations"]:
        for key1 in key["Instances"]:
            InstanceId = key1["InstanceId"]
            ImageId = key1["ImageId"]
            State = key1["State"]["Name"]
            try:
                for key2 in key["Instances"][0]["Tags"]:
                    Tags = key2["Value"]
            except:
                Tags = None

        print(Tags, InstanceId, State)
    print("")
    input("Press Enter to continue")
    return


def start_instances(client):
    """
    Start an AWS instance with instance ID.
    """
    print("Start an instance")
    instanceId = input("Enter instance ID: ")
    response = client.start_instances(InstanceIds=[instanceId])
    print(response)
    input("Press Enter to continue")
    return


def stop_instances(client):
    """
    Stop an AWS instance with instance ID.
    """
    print("Stop an instance")
    instanceId = input("Enter instance ID: ")
    response = client.stop_instances(InstanceIds=[instanceId])
    print(response)
    input("Press Enter to continue")
    return



#!/usr/bin/env python
from os import system

def check_domain_availability(client):
    """
    Search for domain registration availability
    """
    domainName = input("Enter domain name: ")
    response = client.check_domain_availability(DomainName=domainName)
    print(response["Availability"])
    print("")
    input("Press Enter to continue")
    return
